@@ -1,6 +1,7 @@
 #define ERR_PRO_INVALID_ARGUMENT 1
 #define ERR_PRO_FILE_NOT_FOUND 2
 #define ERR_PRO_CANT_OPEN_FILE 3
+#define ERR_PRO_TEMPLATE_SYNTAX_ERROR 4
 
 #include "pstring.h"
 #include "tmpllog.h"
@@ -11,6 +12,14 @@ struct tmplpro_param;
 static int tmplpro_exec_tmpl_filename (struct tmplpro_param* ProParams,const char* filename);
 static int tmplpro_exec_tmpl_scalarref (struct tmplpro_param* ProParams, PSTRING memarea);
 
+static const char* const errlist[] = { 
+  "ok",
+  "invalid argument",
+  "file not found",
+  "can't open file",
+  "syntax error in template"
+};
+
 /* 
  * Local Variables:
  * mode: c 
